# Pytest-executable

`pytest-executable` is a [pytest](https://docs.pytest.org/en/latest/) plugin
for checking and validating executables. This project is still young, but
already used in a professional environment.

## Documentation

The project documentation is available
[online](https://pytest-executable.readthedocs.io/en/latest) (or in the
[`doc`](doc) directory of the repository if you are fluent in
reStructuredText).

## Installation and Usage

A `pytest-executable` package will soon be available in the Conda-Forge and
PyPi repositories (just a matter of free time). In the meantime, you can get
`pytest-executable` by cloning the project repository on Github:

```bash
git clone https://github.com/CS-SI/pytest-executable.git
```

The components required for `pytest-executable` and how to install them are
described in the
[documentation](https://pytest-executable.readthedocs.io/en/latest/installation.html).

## Contributing

A contributing guide will be soon available (once again, just a matter of free
time).

Please fill an issue on the
[Github issue tracker](https://github.com/CS-SI/pytest-executable/issues) for
any bug report, feature request or question.

## Authors

* **[Antoine Dechaume](https://github.com/AntoineD)** - *Project creator and maintainer*

## Copyright and License

Copyright 2020, [CS GROUP](http://www.csgroup.eu)

`pytest-executable` is a free and open source software, distributed under the
Apache License 2.0. See the [`LICENSE.txt`](LICENSE.txt) file for more
information, or the
[quick summary](https://tldrlegal.com/license/apache-license-2.0-(apache-2.0)) of
this license on [tl;drLegal](https://tldrlegal.com/) website.
